@@ -3,6 +3,8 @@ from hcdk_utils.halloumi_users import HalloumiUsers  # noqa: F401
 from hcdk_utils.halloumi_mq_alarms import HalloumiMqAlarms  # noqa: F401
 from hcdk_utils.halloumi_database_alarms import HalloumiDatabaseAlarms  # noqa: F401, E501
 from hcdk_utils.halloumi_rds_snapshot_alarms import HalloumiRdsSnapshotAlarms  # noqa: F401, E501
+from hcdk_utils.halloumi_elasticache_alarms import HalloumiElasticacheAlarms  # noqa: F401, E501
+from hcdk_utils.halloumi_documentdb_alarms import HalloumiDocumentDbAlarms  # noqa: F401, E501
 
 from hcdk_utils.utils.check_cdk import check_cdk   # noqa: F401
 from hcdk_utils.utils.parameters import *   # noqa: F401, F403
