@@ -12,13 +12,15 @@ from .utils import (
 class HalloumiElasticacheAlarms(object):
 
     def __init__(
-        self,
-        scope,
-        stack_name,
-        cache_cluster_id,
-        alarm_topic
-    ):
+            self,
+            scope: core.Construct,
+            stack_name: str,
+            cache_cluster_id: str,
+            alarm_topic: str):
 
+        GREATER_THAN_OR_EQUAL_TO_THRESHOLD = (
+            cloudwatch.ComparisonOperator.GREATER_THAN_OR_EQUAL_TO_THRESHOLD
+        )
         threshold_cpu_usage = int(get_optional(
             'ELASTICACHE_THRESHOLD_CPU_USAGE',
             80
@@ -80,7 +82,7 @@ class HalloumiElasticacheAlarms(object):
             evaluation_periods=evaluation_period,
             threshold=threshold_cpu_usage,
             alarm_description='Alarm for high CPU usage',
-            comparison_operator=self.GREATER_THAN_OR_EQUAL_TO_THRESHOLD,
+            comparison_operator=GREATER_THAN_OR_EQUAL_TO_THRESHOLD,
             period=period_cpu_usage,
             statistic='Maximum'
         )
@@ -102,7 +104,7 @@ class HalloumiElasticacheAlarms(object):
             evaluation_periods=evaluation_period,
             threshold=threshold_swap_usage,
             alarm_description='Alarm for high swap usage',
-            comparison_operator=self.GREATER_THAN_OR_EQUAL_TO_THRESHOLD,
+            comparison_operator=GREATER_THAN_OR_EQUAL_TO_THRESHOLD,
             period=period_swap_usage,
             statistic='Average',
             treat_missing_data=cloudwatch.TreatMissingData.NOT_BREACHING
@@ -125,7 +127,7 @@ class HalloumiElasticacheAlarms(object):
             evaluation_periods=evaluation_period,
             threshold=threshold_number_of_evictions,
             alarm_description='Alarm for high number of evictions',
-            comparison_operator=self.GREATER_THAN_OR_EQUAL_TO_THRESHOLD,
+            comparison_operator=GREATER_THAN_OR_EQUAL_TO_THRESHOLD,
             period=period_number_of_evictions,
             statistic='Average',
             treat_missing_data=cloudwatch.TreatMissingData.NOT_BREACHING
@@ -148,7 +150,7 @@ class HalloumiElasticacheAlarms(object):
             evaluation_periods=evaluation_period,
             threshold=threshold_number_of_connections,
             alarm_description='Alarm for high number of connections',
-            comparison_operator=self.GREATER_THAN_OR_EQUAL_TO_THRESHOLD,
+            comparison_operator=GREATER_THAN_OR_EQUAL_TO_THRESHOLD,
             period=period_number_of_connections,
             statistic='Average',
             treat_missing_data=cloudwatch.TreatMissingData.NOT_BREACHING
