@@ -15,13 +15,12 @@ class HalloumiVpcAlarms(object):
     )
 
     def __init__(
-        self,
-        scope,
-        vpc,
-        stack_name,
-        alarmtopic,
-        alarm_description
-    ) -> None:
+            self,
+            scope: core.Construct,
+            vpc: ec2.IVpc,
+            stack_name: str,
+            alarmtopic: str,
+            alarm_description: str) -> None:
 
         # region Settings
 
